History
=======

This package was developed internally at Equinor starting in 2017
based on several internal codes in Python and other
languages. Open sourced (LGPLv3) in 2019.

Release history

  * v0.4.0 - Feb 2020 - Added command line tool
  * v0.3.0 - Dec 2019 - Rewritten interpolation code
  * v0.2.0 - Nov 2019 - Includes PyscalFactory for creating objects.
  * v0.1.0 - June 2019 - first open source version

Detailed release history at

  * https://github.com/equinor/pyscal/releases
